@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1998-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -119,7 +119,8 @@ ostream& operator << (ostream&o, ivl_switch_type_t val)
 
 static inline void dump_scope_path(ostream&o, const NetScope*scope)
 {
-      if (const NetScope*parent = scope->parent()) {
+      const NetScope*parent = scope->parent();
+      if (parent) {
 	    dump_scope_path(o, parent);
 	    o << ".";
       }
@@ -940,7 +941,7 @@ void NetEvProbe::dump_node(ostream&o, unsigned ind) const
 	    o << "negedge ";
 	    break;
       }
-      o << setw(ind) << "" << "-> " << event_->name() << "; " << endl;
+      o << setw(ind) << "" << "-> " << scope_path(event_->scope()) << "." << event_->name() << "; " << endl;
       dump_node_pins(o, ind+4);
       dump_obj_attr(o, ind+4);
 }
@@ -956,10 +957,10 @@ void NetEvWait::dump(ostream&o, unsigned ind) const
       o << setw(ind) <<"" << "@(";
 
       if (nevents() > 0)
-	    o << event(0)->name();
+	    o << scope_path(event(0)->scope()) << "." << event(0)->name();
 
       for (unsigned idx = 1 ;  idx < nevents() ;  idx += 1)
-	    o << " or " << event(idx)->name();
+	    o << " or " << scope_path(event(idx)->scope()) << "." << event(idx)->name();
 
       o << ")  // " << get_fileline() << endl;
 
@@ -980,10 +981,10 @@ void NetEvWait::dump_inline(ostream&o) const
       o << "@(";
 
       if (nevents() > 0)
-	    o << event(0)->name();
+	    o << scope_path(event(0)->scope()) << "." << event(0)->name();
 
       for (unsigned idx = 1 ;  idx < nevents() ;  idx += 1)
-	    o << " or " << event(idx)->name();
+	    o << " or " << scope_path(event(idx)->scope())<<"."<<event(idx)->name();
 
       o << ") ";
 }
