@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -73,23 +73,20 @@ NetNet* PEConcat::elaborate_lnet_common_(Design*des, NetScope*scope,
 		  nets[idx] = parms_[idx]->elaborate_lnet(des, scope);
 	    }
 
-	    if (nets[idx] == 0) errors += 1;
-	    else if (nets[idx]->data_type() == IVL_VT_REAL) {
+	    if (nets[idx] == 0) {
+                  errors += 1;
+            } else if (nets[idx]->data_type() == IVL_VT_REAL) {
 		  cerr << parms_[idx]->get_fileline() << ": error: "
 		       << "concatenation operand can no be real: "
 		       << *parms_[idx] << endl;
 		  errors += 1;
 		  continue;
-	    } else width += nets[idx]->vector_width();
-
+	    } else {
+                  width += nets[idx]->vector_width();
+            }
       }
 
-	/* If any of the sub expressions failed to elaborate, then
-	   delete all those that did and abort myself. */
       if (errors) {
-	    for (unsigned idx = 0 ;  idx < nets.count() ;  idx += 1) {
-		  if (nets[idx]) delete nets[idx];
-	    }
 	    des->errors += errors;
 	    return 0;
       }
@@ -170,6 +167,28 @@ NetNet* PEConcat::elaborate_bi_net(Design*des, NetScope*scope) const
       return elaborate_lnet_common_(des, scope, true);
 }
 
+bool PEConcat::is_collapsible_net(Design*des, NetScope*scope) const
+{
+      assert(scope);
+
+        // Repeat concatenations are not currently supported.
+      if (repeat_)
+            return false;
+
+	// Test the operands of the concatenation.
+      for (unsigned idx = 0 ;  idx < parms_.count() ;  idx += 1) {
+
+              // Empty expressions are not allowed in concatenations
+	    if (parms_[idx] == 0)
+                  return false;
+
+	    if (!parms_[idx]->is_collapsible_net(des, scope))
+                  return false;
+      }
+
+      return true;
+}
+
 /*
  * A private method to create an implicit net.
  */
@@ -440,14 +459,6 @@ NetNet* PEIdent::elaborate_lnet_common_(Design*des, NetScope*scope,
 	    return 0;
       }
 
-      if (sig->port_type() == NetNet::PINPUT) {
-	    cerr << get_fileline() << ": warning: L-value ``"
-		 << sig->name() << "'' is also an input port." << endl;
-	    cerr << sig->get_fileline() << ": warning: input "
-		 << sig->name() << "; is coerced to inout." << endl;
-	    sig->port_type(NetNet::PINOUT);
-      }
-
 	// Default part select is the entire word.
       unsigned midx = sig->vector_width()-1, lidx = 0;
 	// The default word select is the first.
@@ -507,7 +518,7 @@ NetNet* PEIdent::elaborate_lnet_common_(Design*des, NetScope*scope,
 	      /* The array has a part/bit select at the end. */
 	    if (name_tail.index.size() > sig->array_dimensions()) {
 		  if (sig->get_scalar()) {
-		        cerr << get_fileline() << ": error: " 
+		        cerr << get_fileline() << ": error: "
 		             << "can not select part of ";
 			if (sig->data_type() == IVL_VT_REAL) cerr << "real";
 			else cerr << "scalar";
@@ -522,7 +533,7 @@ NetNet* PEIdent::elaborate_lnet_common_(Design*des, NetScope*scope,
 		        return 0;
 
 		  if (lidx_tmp < 0) {
-		        cerr << get_fileline() << ": sorry: part selects " 
+		        cerr << get_fileline() << ": sorry: part selects "
 		                "straddling the start of signal (" << path_
 		             << ") are not currently supported." << endl;
 		        des->errors += 1;
@@ -533,7 +544,7 @@ NetNet* PEIdent::elaborate_lnet_common_(Design*des, NetScope*scope,
 	    }
       } else if (!name_tail.index.empty()) {
 	    if (sig->get_scalar()) {
-		  cerr << get_fileline() << ": error: " 
+		  cerr << get_fileline() << ": error: "
 		       << "can not select part of ";
 		  if (sig->data_type() == IVL_VT_REAL) cerr << "real: ";
 		  else cerr << "scalar: ";
@@ -547,7 +558,7 @@ NetNet* PEIdent::elaborate_lnet_common_(Design*des, NetScope*scope,
 		  return 0;
 
 	    if (lidx_tmp < 0) {
-		  cerr << get_fileline() << ": sorry: part selects " 
+		  cerr << get_fileline() << ": sorry: part selects "
 		          "straddling the start of signal (" << path_
                        << ") are not currently supported." << endl;
 		  des->errors += 1;
@@ -716,22 +727,20 @@ NetNet* PEIdent::elaborate_port(Design*des, NetScope*scope) const
       switch (sig->port_type()) {
 
 	  case NetNet::PINPUT:
-	    ps = new NetPartSelect(sig, sig->sb_to_idx(lidx), swid,
-				   NetPartSelect::PV);
+	    ps = new NetPartSelect(sig, lidx, swid, NetPartSelect::PV);
 	    connect(tmp->pin(0), ps->pin(0));
 	    sig = tmp;
 	    break;
 
 	  case NetNet::POUTPUT:
-	    ps = new NetPartSelect(sig, sig->sb_to_idx(lidx), swid,
-				   NetPartSelect::VP);
+	    ps = new NetPartSelect(sig, lidx, swid, NetPartSelect::VP);
 	    connect(tmp->pin(0), ps->pin(0));
 	    sig = tmp;
 	    break;
 
 	  case NetNet::PINOUT:
 	    ps = new NetTran(scope, scope->local_symbol(), sig->vector_width(),
-			     swid, sig->sb_to_idx(lidx));
+			     swid, lidx);
 	    connect(sig->pin(0), ps->pin(0));
 	    connect(tmp->pin(0), ps->pin(1));
 	    sig = tmp;
@@ -747,3 +756,27 @@ NetNet* PEIdent::elaborate_port(Design*des, NetScope*scope) const
 
       return sig;
 }
+
+bool PEIdent::is_collapsible_net(Design*des, NetScope*scope) const
+{
+      assert(scope);
+
+      NetNet*       sig = 0;
+      const NetExpr*par = 0;
+      NetEvent*     eve = 0;
+
+      symbol_search(this, des, scope, path_, sig, par, eve);
+
+      if (eve != 0)
+            return false;
+
+      if (sig == 0)
+            return false;
+
+      assert(sig);
+
+      if (sig->type() == NetNet::REG)
+            return false;
+
+      return true;
+}
