@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2011 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2012 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -150,19 +150,6 @@ static void elaborate_parm_item_(perm_string name,
 	    return;
       }
 
-      if (signed_flag) {
-	      /* If explicitly signed, then say so. */
-	    val->cast_signed(true);
-      } else if (cur.msb) {
-	      /* If there is a range, then the signedness comes
-		 from the type and not the expression. */
-	    val->cast_signed(signed_flag);
-      } else {
-	      /* otherwise, let the expression describe
-		 itself. */
-	    signed_flag = val->has_sign();
-      }
-
       val = scope->set_parameter(name, val, cur.type, msb, lsb, signed_flag,
                                  range_list, cur);
       delete val;
@@ -1030,6 +1017,37 @@ void PGenerate::elaborate_subscope_(Design*des, NetScope*scope)
 	    scope->add_genvar((*cur).first, (*cur).second);
       }
 
+	// Scan the localparams in this scope, and create stub parameter
+        // entries in the scope for the parameter names.
+      collect_scope_localparams_(scope, localparams);
+
+	// Now scan the localparams again, this time elaborating them
+	// for use as parameter values.
+      elaborate_scope_localparams_(des, scope, localparams);
+
+	// Run through the defparams for this module, elaborate the
+	// expressions in this context and save the result is a table
+	// for later final override.
+
+	// It is OK to elaborate the expressions of the defparam here
+	// because Verilog requires that the expressions only use
+	// local parameter names. It is *not* OK to do the override
+	// here because the parameter receiving the assignment may be
+	// in a scope not discovered by this pass.
+
+      typedef list<PGenerate::named_expr_t>::const_iterator defparms_iter_t;
+      for (defparms_iter_t cur = defparms.begin()
+		 ; cur != defparms.end() ;  cur ++) {
+
+	    PExpr*ex = cur->second;
+	    assert(ex);
+
+	    NetExpr*val = ex->elaborate_pexpr(des, scope);
+	    if (val == 0) continue;
+
+	    scope->defparams.push_back(make_pair(cur->first, val));
+      }
+
 	// Scan the generated scope for nested generate schemes,
 	// and *generate* new scopes, which is slightly different
 	// from simple elaboration.
@@ -1040,14 +1058,6 @@ void PGenerate::elaborate_subscope_(Design*des, NetScope*scope)
 	    (*cur) -> generate_scope(des, scope);
       }
 
-	// Scan the localparams in this scope, and create stub parameter
-        // entries in the scope for the parameter names.
-      collect_scope_localparams_(scope, localparams);
-
-	// Now scan the localparams again, this time elaborating them
-	// for use as parameter values.
-      elaborate_scope_localparams_(des, scope, localparams);
-
         // Scan through all the task and function declarations in this
         // scope.
       elaborate_scope_tasks(des, scope, *this, tasks);
