@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2007-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -20,7 +20,7 @@
 #ifndef __ivl_assert_h
 #define __ivl_assert_h
 
-# include  <assert.h>
+# include  <cassert>
 
 #define ivl_assert(tok, expression)  \
       do {			    \
