@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.0.2 */
+/* ANSI-C code produced by gperf version 3.0.4 */
 /* Command-line: gperf -o -i 7 -C -k '1-4,$' -L ANSI-C -H keyword_hash -N check_identifier -t ./lexor_keyword.gperf  */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -110,6 +110,9 @@ keyword_hash (register const char *str, register unsigned int len)
 
 #ifdef __GNUC__
 __inline
+#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+__attribute__ ((__gnu_inline__))
+#endif
 #endif
 const struct lexor_keyword *
 check_identifier (register const char *str, register unsigned int len)
