@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2003-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -36,11 +36,8 @@ char* acc_fetch_type_str(PLI_INT32 type)
 
 	  case accConstant:
 	    return "accConstant";
-
-	  default:
-	    vpi_printf("XXXX acc_fetch_type_str(%d);\n", (int)type);
-	    return "acc_fetch_type_str(unknown)";
       }
 
-      return "";
+      vpi_printf("acc_fetch_type_str: type %d is what accType?\n", (int)type);
+      return "acc_fetch_type_str(unknown)";
 }
