@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2009 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1998-2010 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -269,7 +269,7 @@ bool NetPins::is_linked(void)
 NetObj::NetObj(NetScope*s, perm_string n, unsigned np)
 : NetPins(np), scope_(s), name_(n), delay1_(0), delay2_(0), delay3_(0)
 {
-      /* Don't 
+      /* Don't
       ivl_assert(*this, np > 0);
        * because it would happen before we get to print a useful
        * message in the NetNet constructor
@@ -904,9 +904,9 @@ NetPartSelect::NetPartSelect(NetNet*sig, unsigned off, unsigned wid,
 }
 
 NetPartSelect::NetPartSelect(NetNet*sig, NetNet*sel,
-			     unsigned wid, bool signed_flag)
+			     unsigned wid, bool signed_flag__)
 : NetNode(sig->scope(), sig->scope()->local_symbol(), 3),
-    off_(0), wid_(wid), dir_(VP), signed_flag_(signed_flag)
+    off_(0), wid_(wid), dir_(VP), signed_flag_(signed_flag__)
 {
       switch (dir_) {
 	  case NetPartSelect::VP:
@@ -2725,7 +2725,11 @@ DelayType NetCondit::delay_type() const
       } else {
 	      /* Because of the indeterminate conditional value the
 	       * best we can have for this case is a possible delay. */
-	    result = combine_delays(if_->delay_type(), NO_DELAY);
+	    if (if_) {
+		  result = combine_delays(if_->delay_type(), NO_DELAY);
+	    } else {
+		  result = NO_DELAY;
+	    }
       }
 
       return result;
