@@ -1,7 +1,7 @@
 #ifndef __pform_H
 #define __pform_H
 /*
- * Copyright (c) 1998-2010 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1998-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -254,7 +254,8 @@ extern void pform_set_port_type(const struct vlltype&li,
 				list<perm_string>*names,
 				svector<PExpr*>*range,
 				bool signed_flag,
-				NetNet::PortType);
+				NetNet::PortType,
+				svector<named_pexpr_t*>*attr);
 extern void pform_set_port_type(perm_string nm, NetNet::PortType pt,
 				const char*file, unsigned lineno);
 
@@ -356,7 +357,8 @@ extern svector<PWire*>*pform_make_task_ports(NetNet::PortType pt,
 					     svector<PExpr*>*range,
 					     list<perm_string>*names,
 					     const char* file,
-					     unsigned lineno);
+					     unsigned lineno,
+					     bool isint = false);
 
 
 /*
