@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2010 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -35,7 +35,7 @@
 
 static const char*version_string =
 "Icarus Verilog STUB Code Generator " VERSION " (" VERSION_TAG ")\n\n"
-"Copyright (c) 2000-2009 Stephen Williams (steve@icarus.com)\n\n"
+"Copyright (c) 2000-2011 Stephen Williams (steve@icarus.com)\n\n"
 "  This program is free software; you can redistribute it and/or modify\n"
 "  it under the terms of the GNU General Public License as published by\n"
 "  the Free Software Foundation; either version 2 of the License, or\n"
@@ -225,7 +225,7 @@ static void show_lpm_arithmetic_pins(ivl_lpm_t net)
 {
       ivl_nexus_t nex;
       nex = ivl_lpm_q(net, 0);
-      fprintf(out, "    Q: %p\n", ivl_lpm_q(net, 0));
+      fprintf(out, "    Q: %p\n", nex);
 
       nex = ivl_lpm_data(net, 0);
       fprintf(out, "    DataA: %p\n", nex);
@@ -243,7 +243,7 @@ static void show_lpm_abs(ivl_lpm_t net)
 	      ivl_lpm_basename(net), width);
 
       nex = ivl_lpm_q(net, 0);
-      fprintf(out, "    Q: %p\n", ivl_lpm_q(net, 0));
+      fprintf(out, "    Q: %p\n", nex);
 
       nex = ivl_lpm_data(net, 0);
       fprintf(out, "    D: %p\n", nex);
@@ -684,6 +684,7 @@ static void show_lpm_re(ivl_lpm_t net)
 	    break;
 	  case IVL_LPM_RE_NOR:
 	    type = "NOR";
+	    break;
 	  case IVL_LPM_RE_XOR:
 	    type = "XOR";
 	    break;
@@ -1525,7 +1526,7 @@ static void show_logic(ivl_net_logic_t net)
 static int show_scope(ivl_scope_t net, void*x)
 {
       unsigned idx;
-      char *is_auto;
+      const char *is_auto;
 
       fprintf(out, "scope: %s (%u parameters, %u signals, %u logic)",
 	      ivl_scope_name(net), ivl_scope_params(net),
