@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2010 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -219,7 +219,7 @@ static void eval_logic_into_integer(ivl_expr_t expr, unsigned ix)
 		unsigned word = 0;
 		if (ivl_signal_dimensions(sig) > 0) {
 		      ivl_expr_t ixe;
-		      char*type = ivl_expr_signed(expr) ? "/s" : "";
+		      const char*type = ivl_expr_signed(expr) ? "/s" : "";
 
 			/* Detect the special case that this is a
 			   variable array. In this case, the ix/getv
@@ -246,7 +246,7 @@ static void eval_logic_into_integer(ivl_expr_t expr, unsigned ix)
 		            break;
 		      }
 		}
-		char*type = ivl_signal_signed(sig) ? "/s" : "";
+		const char*type = ivl_signal_signed(sig) ? "/s" : "";
 		fprintf(vvp_out, "    %%ix/getv%s %u, v%p_%u;\n", type, ix,
 		                 sig, word);
 		break;
@@ -1157,8 +1157,9 @@ static struct vector_info draw_binary_expr_lrs(ivl_expr_t expr, unsigned wid)
 	  case 'l': /* << (left shift) */
 	    lv = draw_eval_expr_wid(le, wid, 0);
 
-	      /* shifting 0 gets 0. */
-	    if (lv.base == 0)
+	      /* Shifting 0 gets 0, if we can be sure the shift value
+                 contains no 'x' or 'z' bits. */
+	    if ((lv.base == 0) && (ivl_expr_value(re) == IVL_VT_BOOL))
 		  return lv;
 
 	    if (lv.base < 4) {
@@ -1193,8 +1194,9 @@ static struct vector_info draw_binary_expr_lrs(ivl_expr_t expr, unsigned wid)
 		  lv = draw_eval_expr_wid(le, ivl_expr_width(le), 0);
 	    }
 
-	      /* shifting 0 gets 0. */
-	    if (lv.base == 0)
+	      /* Shifting 0 gets 0, if we can be sure the shift value
+                 contains no 'x' or 'z' bits. */
+	    if ((lv.base == 0) && (ivl_expr_value(re) == IVL_VT_BOOL))
 		  return lv;
 
 	    if (lv.base < 4) {
@@ -1229,13 +1231,15 @@ static struct vector_info draw_binary_expr_lrs(ivl_expr_t expr, unsigned wid)
 		  lv = draw_eval_expr_wid(le, ivl_expr_width(le), 0);
 	    }
 
-	      /* shifting 0 gets 0. */
-	    if (lv.base == 0)
+	      /* Shifting 0 gets 0, if we can be sure the shift value
+                 contains no 'x' or 'z' bits. */
+	    if ((lv.base == 0) && (ivl_expr_value(re) == IVL_VT_BOOL))
 		  return lv;
 
-	      /* Sign extend any constant begets itself, if this
-		 expression is signed. */
-	    if ((lv.base < 4) && (ivl_expr_signed(expr)))
+	      /* Similarly, sign extending any constant bit begets itself,
+                 if this expression is signed. */
+	    if ((lv.base < 4) && ivl_expr_signed(expr)
+                && (ivl_expr_value(re) == IVL_VT_BOOL))
 		  return lv;
 
 	    if (lv.base < 4) {
@@ -1565,10 +1569,10 @@ static struct vector_info draw_binary_expr_arith(ivl_expr_t expr, unsigned wid)
 
 	  case 'p':
 	    if (ivl_expr_signed(le) || ivl_expr_signed(re)) {
-		  fprintf(vvp_out, "    %%pow/s %u, %u, %u;\n", 
+		  fprintf(vvp_out, "    %%pow/s %u, %u, %u;\n",
 		          lv.base, rv.base, wid);
 	    } else {
-		  fprintf(vvp_out, "    %%pow %u, %u, %u;\n", 
+		  fprintf(vvp_out, "    %%pow %u, %u, %u;\n",
 		          lv.base, rv.base, wid);
 	    }
 	    break;
@@ -1729,7 +1733,7 @@ static struct vector_info draw_concat_expr(ivl_expr_t expr, unsigned wid,
 			fprintf(vvp_out, "    %%mov %u, %u, %u; Reuse "
 			                 "calculated expression.\n",
 			                 res.base+off, avec.base, awid);
-			clr_vector(avec); 
+			clr_vector(avec);
 		  } else {
 			struct vector_info dest;
 
@@ -1748,7 +1752,7 @@ static struct vector_info draw_concat_expr(ivl_expr_t expr, unsigned wid,
 		    /* Clear the temporary space and return nothing.
 		     * This will be caught in draw_eval_expr_dest()
 		     * and dropped. */
-		  clr_vector(res); 
+		  clr_vector(res);
 		  res.base = 0;
 		  res.wid = 0;
 	    }
@@ -1782,7 +1786,7 @@ static struct vector_info draw_concat_expr(ivl_expr_t expr, unsigned wid,
 
 	    fprintf(vvp_out, "    %%mov %u, %u, %u;\n", res.base,
 	                     full_res.base, wid);
-	    clr_vector(full_res); 
+	    clr_vector(full_res);
       }
 
 	/* Save the accumulated result in the lookaside map. */
