@@ -768,7 +768,8 @@ verinum::V operator <= (const verinum&left, const verinum&right)
 {
       verinum::V left_pad = verinum::V0;
       verinum::V right_pad = verinum::V0;
-      if (left.has_sign() && right.has_sign()) {
+      bool signed_calc = left.has_sign() && right.has_sign();
+      if (signed_calc) {
 	    left_pad = left.get(left.len()-1);
 	    right_pad = right.get(right.len()-1);
 
@@ -780,11 +781,23 @@ verinum::V operator <= (const verinum&left, const verinum&right)
 
       unsigned idx;
       for (idx = left.len() ; idx > right.len() ;  idx -= 1) {
-	    if (left[idx-1] != right_pad) return verinum::V0;
+	    if (left[idx-1] != right_pad) {
+		      // A change of padding for a negative left argument
+		      // denotes the left value is less than the right.
+		   return (signed_calc &&
+		           (left_pad == verinum::V1)) ? verinum::V1 :
+		                                        verinum::V0;
+	    }
       }
 
       for (idx = right.len() ; idx > left.len() ;  idx -= 1) {
-	    if (right[idx-1] != left_pad) return verinum::V1;
+	    if (right[idx-1] != left_pad) {
+		      // A change of padding for a negative right argument
+		      // denotes the left value is not less than the right.
+		   return (signed_calc &&
+		           (right_pad == verinum::V1)) ? verinum::V0 :
+		                                         verinum::V1;
+	    }
       }
 
       idx = right.len();
@@ -807,7 +820,8 @@ verinum::V operator < (const verinum&left, const verinum&right)
 {
       verinum::V left_pad = verinum::V0;
       verinum::V right_pad = verinum::V0;
-      if (left.has_sign() && right.has_sign()) {
+      bool signed_calc = left.has_sign() && right.has_sign();
+      if (signed_calc) {
 	    left_pad = left.get(left.len()-1);
 	    right_pad = right.get(right.len()-1);
 
@@ -819,11 +833,23 @@ verinum::V operator < (const verinum&left, const verinum&right)
 
       unsigned idx;
       for (idx = left.len() ; idx > right.len() ;  idx -= 1) {
-	    if (left[idx-1] != right_pad) return verinum::V0;
+	    if (left[idx-1] != right_pad) {
+		      // A change of padding for a negative left argument
+		      // denotes the left value is less than the right.
+		   return (signed_calc &&
+		           (left_pad == verinum::V1)) ? verinum::V1 :
+		                                        verinum::V0;
+	    }
       }
 
       for (idx = right.len() ; idx > left.len() ;  idx -= 1) {
-	    if (right[idx-1] != left_pad) return verinum::V1;
+	    if (right[idx-1] != left_pad) {
+		      // A change of padding for a negative right argument
+		      // denotes the left value is not less than the right.
+		   return (signed_calc &&
+		           (right_pad == verinum::V1)) ? verinum::V0 :
+		                                         verinum::V1;
+	    }
       }
 
       while (idx > 0) {
@@ -1053,15 +1079,17 @@ verinum pow(const verinum&left, const verinum&right)
       long pow_count = right.as_long();
 
 	// We need positive and negative one in a few places.
-      verinum one (verinum::V0, left.len(), left.has_len());
+      unsigned len = left.len();
+	// Positive one must be at least two bits wide!
+      verinum one (verinum::V0, (len<2) ? 2 : len, left.has_len());
       one.has_sign(left.has_sign());
       one.set(0, verinum::V1);
-      verinum m_one (verinum::V1, left.len(), left.has_len());
+      verinum m_one (verinum::V1, len, left.has_len());
       m_one.has_sign(true);
 
 	// If either the right or left values are undefined we return 'bx.
       if (!right.is_defined() || !left.is_defined()) {
-	    result = verinum(verinum::Vx, left.len(), left.has_len());
+	    result = verinum(verinum::Vx, len, left.has_len());
 	    result.has_sign(left.has_sign());
 	// If the right value is zero we need to set the result to 1.
       } else if (pow_count == 0)  {
@@ -1069,7 +1097,7 @@ verinum pow(const verinum&left, const verinum&right)
       } else if (pow_count < 0) {
 	      // 0 ** <negative> is 'bx.
 	    if (left.is_zero()) {
-		  result = verinum(verinum::Vx, left.len(), left.has_len());
+		  result = verinum(verinum::Vx, len, left.has_len());
 		  result.has_sign(left.has_sign());
 	      // 1 ** <negative> is 1.
 	    } else if (left == one) {
@@ -1083,7 +1111,7 @@ verinum pow(const verinum&left, const verinum&right)
 		  }
 	      // Everything else is 0.
 	    } else {
-		  result = verinum(verinum::V0, left.len(), left.has_len());
+		  result = verinum(verinum::V0, len, left.has_len());
 		  result.has_sign(left.has_sign());
 	    }
       }
