@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2008 Tony Bybell.
+ * Copyright (c) 2003-2012 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -663,11 +663,24 @@ if((lt)&&(lt->numfacs))
 			lt->sorted_facs[i]->facnum = i;
 			}
 
-		lt->facname_offset=lt->position;
+                if(!lt->timezero)
+                        {
+                        lxt2_wr_emit_u32(lt, lt->numfacs);       /* uncompressed */
+                        }
+                        else
+                        {
+                        lxt2_wr_emit_u32(lt, 0);                 /* uncompressed, flag to insert extra parameters */
+                        lxt2_wr_emit_u32(lt, 8);                 /* uncompressed 8 counts timezero and on */
+                        lxt2_wr_emit_u32(lt, lt->numfacs);       /* uncompressed */
+                        lxt2_wr_emit_u64(lt, (lt->timezero >> 32) & 0xffffffffL, lt->timezero & 0xffffffffL); /* uncompressed */
+                        }
+
 
-		lxt2_wr_emit_u32(lt, lt->numfacs);	/* uncompressed */
 		lxt2_wr_emit_u32(lt, lt->numfacbytes);	/* uncompressed */
 		lxt2_wr_emit_u32(lt, lt->longestname);	/* uncompressed */
+
+		lt->facname_offset=lt->position;
+
 		lxt2_wr_emit_u32(lt, 0); 		/* uncompressed : placeholder for zfacnamesize     */
 		lxt2_wr_emit_u32(lt, 0);		/* uncompressed : placeholder for zfacname_predec_size */
 		lxt2_wr_emit_u32(lt, 0); 		/* uncompressed : placeholder for zfacgeometrysize */
@@ -720,7 +733,7 @@ if((lt)&&(lt->numfacs))
 		lt->break_header_size = lt->position;			/* in case we need to emit multiple lxt2s with same header */
 		lt->zfacgeometry_size = lt->position - lt->facgeometry_offset;
 
-		fseeko(lt->handle, lt->facname_offset + 12, SEEK_SET);
+		fseeko(lt->handle, lt->facname_offset, SEEK_SET);
 		lxt2_wr_emit_u32(lt, lt->zfacname_size);		/* backpatch sizes... */
 		lxt2_wr_emit_u32(lt, lt->zfacname_predec_size);
 		lxt2_wr_emit_u32(lt, lt->zfacgeometry_size);
@@ -2174,7 +2187,19 @@ void lxt2_wr_set_compression_depth(struct lxt2_wr_trace *lt, unsigned int depth)
 if(lt)
 	{
 	if(depth > 9) depth = 9;
-	sprintf(lt->zmode, "wb%d", depth);
+	sprintf(lt->zmode, "wb%u", depth);
 	}
 }
 
+
+/*
+ * time zero offset      
+ */
+void lxt2_wr_set_timezero(struct lxt2_wr_trace *lt, lxtstime_t timeval)               
+{                        
+if(lt)
+        {                
+        lt->timezero = timeval;
+        }                 
+}
+
