@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-9 Tony Bybell.
+ * Copyright (c) 2001-2012 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -996,8 +996,8 @@ if(rgh) lt_recurse_dictionary_free(lt, rgh);
 
 static int lt_dictval_compare(const void *v1, const void *v2)
 {
-dslxt_Tree *s1 = *(dslxt_Tree **)v1;
-dslxt_Tree *s2 = *(dslxt_Tree **)v2;
+const dslxt_Tree *s1 = *(const dslxt_Tree * const *)v1;
+const dslxt_Tree *s2 = *(const dslxt_Tree * const *)v2;
 
 if(s1->val > s2->val) return(1); else return(-1);	/* they're *never* equal */
 }
@@ -1102,11 +1102,9 @@ if(lt)
 	lt_emitfacs(lt);
 	if(lt->dict) lt_finalize_dictionary(lt);
 
-	if(lt->timebuff)
-		{
-		free(lt->timebuff);
-		lt->timebuff=NULL;
-		}
+	free(lt->timebuff);
+	lt->timebuff=NULL;
+
 	if(lt->timehead)
 		{
 		struct lt_timetrail *t=lt->timehead;
@@ -1210,6 +1208,12 @@ if(lt)
 		lt->dumpoffcount = 0;
 		}
 
+	if(lt->timezero)
+		{
+		lt->timezero_offset = lt->position;
+		lt_emit_u64(lt, (int)((lt->timezero)>>32), (int)lt->timezero);
+		}
+
 	/* prefix */
 	lt_emit_u8(lt, LT_SECTION_END);
 
@@ -1239,6 +1243,9 @@ if(lt)
 	/* Version 5 adds */
 	if(lt->exclude_offset) { lt_emit_u32(lt, lt->exclude_offset); lt_emit_u8(lt, LT_SECTION_EXCLUDE_TABLE); lt->exclude_offset = 0; }
 
+	/* Version 6 adds */
+	if(lt->timezero_offset) { lt_emit_u32(lt, lt->timezero_offset); lt_emit_u8(lt, LT_SECTION_TIMEZERO); lt->timezero_offset = 0; }
+
 	/* suffix */
 	lt_emit_u8(lt, LT_TRLID);
 
@@ -1408,10 +1415,7 @@ if(lt)
 			lt->mintime = lt->maxtime = timeval;
 			}
 
-		if(lt->timebuff)
-			{
-			free(lt->timebuff);
-			}
+		free(lt->timebuff);
 		lt->timebuff = trl;
 		lt->timeval = timeval;
 		rc=1;
@@ -1590,7 +1594,7 @@ if(lt)
 /*
  * emission for trace values..
  */
-static int lt_optimask[]=
+static unsigned int lt_optimask[]=
 {
 0x00000000,
 
@@ -2813,22 +2817,11 @@ if((lt)&&(lt->dumpoff_active))
 	}
 }
 
-/*
- * $Id: lxt_write.c,v 1.4 2009/03/29 00:50:00 gtkwave Exp $
- * $Log: lxt_write.c,v $
- * Revision 1.4  2009/03/29 00:50:00  gtkwave
- * update lt_close() to zero out written section offset/size.
- *
- * Revision 1.3  2009/03/29 00:05:23  gtkwave
- * fixed & to && in if() comparison
- *
- * Revision 1.2  2008/12/20 05:08:26  gtkwave
- * -Wshadow warning cleanups
- *
- * Revision 1.1.1.1  2007/05/30 04:28:14  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:18  gtkwave
- * initial release
- *
- */
+void lt_set_timezero(struct lt_trace *lt, lxtotime_t timeval)
+{
+if(lt)
+	{
+	lt->timezero = timeval;
+	}
+}
+
