@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2010 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2003-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -472,10 +472,11 @@ static PLI_INT32 sys_dumpfile_calltf(PLI_BYTE8*name)
 
         /* $dumpfile must be called before $dumpvars starts! */
       if (dumpvars_status != 0) {
-	    char msg [64];
-	    snprintf(msg, 64, "LXT2 warning: %s:%d:",
+	    char msg[64];
+	    snprintf(msg, sizeof(msg), "LXT2 warning: %s:%d:",
 	             vpi_get_str(vpiFile, callh),
 	             (int)vpi_get(vpiLineNo, callh));
+	    msg[sizeof(msg)-1] = 0;
 	    vpi_printf("%s %s called after $dumpvars started,\n", msg, name);
 	    vpi_printf("%*s using existing file (%s).\n",
 	               (int) strlen(msg), " ", dump_path);
@@ -533,7 +534,6 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
       struct t_cb_data cb;
       struct vcd_info* info;
 
-      const char* type;
       const char* name;
       const char* ident;
       int nexus_id;
@@ -556,7 +556,6 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 
       switch (vpi_get(vpiType, item)) {
 
-	  case vpiNet:  type = "wire";    if(0){
 	  case vpiMemoryWord:
 	    if (vpi_get(vpiConstantSelect, item) == 0) {
 		    /* Turn a non-constant array word select into a
@@ -567,7 +566,8 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 	    }
 	  case vpiIntegerVar:
 	  case vpiTimeVar:
-	  case vpiReg:  type = "reg";    }
+	  case vpiReg:
+	  case vpiNet:
 
 	      /* An array word is implicitly escaped so look for an
 	       * escaped identifier that this could conflict with. */
@@ -660,11 +660,11 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 
 	    break;
 
-	  case vpiModule:      type = "module";      if(0){
-	  case vpiNamedBegin:  type = "begin";      }if(0){
-	  case vpiTask:        type = "task";       }if(0){
-	  case vpiFunction:    type = "function";   }if(0){
-	  case vpiNamedFork:   type = "fork";       }
+	  case vpiModule:
+	  case vpiNamedBegin:
+	  case vpiTask:
+	  case vpiFunction:
+	  case vpiNamedFork:
 
 	    if (depth > 0) {
 		  int nskip;
@@ -687,7 +687,7 @@ static void scan_item(unsigned depth, vpiHandle item, int skip)
 
 		  name = vpi_get_str(vpiName, item);
 
-                  push_scope(name);	/* keep in type info determination for possible future usage */
+                  push_scope(name);
 
 		  for (i=0; types[i]>0; i++) {
 			vpiHandle hand;
