@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2010 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1999-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -75,9 +75,11 @@ static void gen_new_vcd_id(void)
            v /= 94;
            if(!v) {
                  vcdid[i+1] = '\0';
-                 break;
+                 return;
            }
       }
+	// This should never happen since 94**7 is a lot if identifiers!
+      assert(0);
 }
 
 static char *truncate_bitvec(char *s)
@@ -442,10 +444,11 @@ static PLI_INT32 sys_dumpfile_calltf(PLI_BYTE8*name)
 
         /* $dumpfile must be called before $dumpvars starts! */
       if (dumpvars_status != 0) {
-	    char msg [64];
-	    snprintf(msg, 64, "VCD warning: %s:%d:",
+	    char msg[64];
+	    snprintf(msg, sizeof(msg), "VCD warning: %s:%d:",
 	             vpi_get_str(vpiFile, callh),
 	             (int)vpi_get(vpiLineNo, callh));
+	    msg[sizeof(msg)-1] = 0;
 	    vpi_printf("%s %s called after $dumpvars started,\n", msg, name);
 	    vpi_printf("%*s using existing file (%s).\n",
 	               (int) strlen(msg), " ", dump_path);
@@ -708,7 +711,7 @@ static int draw_scope(vpiHandle item, vpiHandle callh)
 {
       int depth;
       const char *name;
-      char *type;
+      const char *type;
 
       vpiHandle scope = vpi_handle(vpiScope, item);
       if (!scope) return 0;
@@ -797,7 +800,7 @@ static PLI_INT32 sys_dumpvars_calltf(PLI_BYTE8*name)
 		  scname = strdup(vpi_get_str(vpiFullName,
 		                              vpi_handle(vpiScope, item)));
 		  fullname = vpi_get_str(vpiFullName, item);
-		  if (((item_type != vpiMemoryWord) && 
+		  if (((item_type != vpiMemoryWord) &&
 		       vcd_names_search(&vcd_tab, scname)) ||
 		      vcd_names_search(&vcd_var, fullname)) {
 		        vpi_printf("VCD warning: skipping signal %s, "
