@@ -565,7 +565,7 @@ extern PLI_INT32 vpi_chk_error(p_vpi_error_info info);
 
 
 /* This is the table of startup routines included in each module. */
-extern DLLEXPORT void (*vlog_startup_routines[])();
+extern DLLEXPORT void (*vlog_startup_routines[])(void);
 
 
 /*
@@ -584,6 +584,25 @@ extern void vpip_format_strength(char*str, s_vpi_value*value, unsigned bit);
 extern void vpip_set_return_value(int value);
 extern s_vpi_vecval vpip_calc_clog2(vpiHandle arg);
 
+/*
+ * Stopgap fix for br916. We need to reject any attempt to pass a thread
+ * variable to $strobe or $monitor. To do this, we use some private VPI
+ * properties that are normally only used by the VVP thread cleanup code.
+ * Normally the following definitions are provided by vvp/vpi_priv.h, but
+ * for the stopgap fix we need to make them more widely available.
+ */
+#define BR916_STOPGAP_FIX
+#ifdef BR916_STOPGAP_FIX
+#define _vpiFromThr 0x1000001
+#   define _vpiNoThr   0
+#   define _vpiString  1
+#   define _vpiVThr    2
+#   define _vpiWord    3
+#   define _vpi_at_PV  4
+#   define _vpi_at_A   5
+#   define _vpi_at_APV 6
+#endif
+
 EXTERN_C_END
 
 #endif
