@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2010 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2011 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -606,6 +606,7 @@ void print_vpi_call_errors()
 	    free(vpi_call_error_lst[idx].name);
       }
       free(vpi_call_error_lst);
+      fflush(stderr);
 }
 
 static void cleanup_vpi_call_args(unsigned argc, vpiHandle*argv)
@@ -633,7 +634,7 @@ static void cleanup_vpi_call_args(unsigned argc, vpiHandle*argv)
  * vbit is also a non-zero value, the address in thread space of the result.
  */
 vpiHandle vpip_build_vpi_call(const char*name, unsigned vbit, int vwid,
-			      class vvp_net_t*fnet,
+			      struct vvp_net_t*fnet,
 			      unsigned argc, vpiHandle*argv,
 			      long file_idx, long lineno)
 {
